/**
 * C-JDBC: Clustered JDBC.
 * Copyright (C) 2002-2004 French National Institute For Research In Computer
 * Science And Control (INRIA).
 * Contact: c-jdbc@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or any later
 * version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * Initial developer(s): Nicolas Modrzyk.
 * Contributor(s): ______________________.
 */

package org.objectweb.cjdbc.scenario.tools.components;

/**
 * This class defines a ComponentInterface. A instance of this class is started and managed
 * by the ComponentManager.
 * 
 * @author <a href="mailto:Nicolas.Modrzyk@inrialpes.fr">Nicolas Modrzyk</a>
 * @version 1.0
 */
public interface ComponentInterface
{
  /**
   * Start this component
   * 
   * @throws Exception if could not start
   */
  void start() throws Exception;

  /**
   * Returns the database value.
   * 
   * @return Returns the database.
   */
  String getDatabase();

  /**
   * Loads the data of the given file in the database  
   * 
   * @param file to load
   * @throws Exception if fails
   */
  void loadDatabase(String file) throws Exception;

  /**
   * Loads a default file in the database
   * 
   * @throws Exception if fails
   */
  void loadDatabase() throws Exception;

  /**
   * Loads the xml file with the given target database

   * @param xml file 
   * @param targetDB target database
   * @throws Exception if fails
   */
  void loadDatabase(String xml, String targetDB) throws Exception;

  /**
   * Returns the port value.
   * 
   * @return Returns the port.
   */
  String getPort();

  /**
   * Returns the process value. 
   * 
   * @return Returns the process.
   */
  Object getProcess();

  /**
   * Remove files generated by this process
   */
  void release();
}