package org.webdocwf.util.loader.wizard;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.border.*;
import java.io.*;
import java.util.*;

public class OctopusGeneratorFrame
    extends JInternalFrame {

  private static final String SOURCE_TYPE = "Source database type",
      TARGET_TYPE = "Target database type",
      SOURCE_DATABASE = "Source database URL",
      TARGET_DATABASE ="Target database URL",
      SOURCE_USER = "Source database user",
      SOURCE_PASSWORD = "Source database password",
      TARGET_USER = "Target database user",
      TARGET_PASSWORD = "Target database password",
      VALUE_MODE = "Value mode",
      GENERATOR_OUTPUT ="Generator output directory",
      DOML_PATH = "Doml URL( when use Doml as input )",
      PACKAGE_NAME = "Package name",
      SOURCE_DRIVER_NAME = "Source database driver name",
      TARGET_DRIVER_NAME ="Target database driver name",
      ADDITIONAL_PATHS = "Additional classpaths",
      DROP_TABLE = "Drop Tables",
      CREATE_TABLE = "Create Tables",
      CREATE_PRIMARY_KEYS = "Create Primary Keys",
      DROP_FOREIGN_KEYS = "Drop Foreign Keys",
      CREATE_FOREIGN_KEYS ="Create Foreign Keys",
      CREATE_INDEXES = "Create Indexes",
      CREATE_SQL_FOR_ALL_VENDORS ="Create SQL Statements for All Vendors",
      GENERATE_DOML = "Generate Doml file",
      GENERATE_XML = "Generate Xml files",
      GENERATE_SQL = "Generate Sql files",
      OPTIMIZED_MODE ="Optimized mode for all tables",
      FULL_MODE = "Full mode for all tables",
      INCLUDE_TABLE_LIST = "Include Table List (e.g. table1;table2)",
      PATH_TO_CONF_IN_JAR = "Path to conf files in jar";

  //dimensions
  private static Dimension bigButton = new Dimension(100, 20);
  private static Dimension smallComponent = new Dimension(150, 20);
  private static Dimension bigComponent = new Dimension(400, 20);
  private static Dimension bigPlusButton = new Dimension(380, 20);
  private static Dimension veryBigComponent = new Dimension(650, 20);
  private static Dimension veryBigPlusButton = new Dimension(630, 20);
  private static Dimension panelComponenet = new Dimension(720, 40);

  JSplitPane main;

  Border loweredBorder = BorderFactory.createEtchedBorder(EtchedBorder.LOWERED);
  Border raisedBorder = BorderFactory.createEtchedBorder(EtchedBorder.RAISED);
  Border bevelBorder = BorderFactory.createLoweredBevelBorder();

  private JCheckBox sqlFiles, xmlFiles, domlFile,
      createTables, createPK, createFK, createIn,
      dropTables, createSQLForAll, dropFK;
  private JRadioButton optimizedMode, fullMode;
  private JTextField packageField, generatorOutput, addPaths;
  private JDesktopPane desktop;
  private OctopusGeneratorData initData;
  private HashMap fields;
  private JTextArea traceArea;

  public OctopusGeneratorFrame(JDesktopPane desktop) {
    super("Octopus Generator Application", true, true, true, true);
	setFrameIcon( new ImageIcon(getClass().getClassLoader().getResource("org/webdocwf/util/loader/"+
		   "wizard/images/Enhydra16.gif")));

    this.desktop = desktop;
    fields = new HashMap();
    //generatorOptions
    JPanel generatorOptionsUp = new JPanel();
    JPanel generatorOptionsDown = new JPanel();

    //generator input data
    JTabbedPane octopusGeneratorData = new JTabbedPane();
    JPanel commonPanel = new JPanel();
    JPanel advancedPanel = new JPanel();
    JPanel outputOptions = new JPanel();
    octopusGeneratorData.addTab("JDBC as source data", commonPanel);
    octopusGeneratorData.addTab("Output options", outputOptions);
    octopusGeneratorData.addTab("Advanced", advancedPanel);

    //generatotOptionsUp panel
    generatorOptionsUp.setLayout(new BoxLayout(generatorOptionsUp, BoxLayout.Y_AXIS));
    generatorOptionsUp.setBorder(BorderFactory.createEtchedBorder(EtchedBorder.LOWERED));
    JButton gotoOct = createOctopusButton("Loader", bigButton);
    gotoOct.setAction(new StartOctopusLoader());
    JButton help = createOctopusButton("Help", bigButton);
    help.setAction(new OctopusHelpAction());
    generatorOptionsUp.add(gotoOct);
    generatorOptionsUp.add(help);

    //generatotOptionsDown panel
    generatorOptionsDown.setLayout(new BoxLayout(generatorOptionsDown, BoxLayout.Y_AXIS));
    generatorOptionsDown.setBorder(BorderFactory.createEtchedBorder(EtchedBorder.LOWERED));
    JButton start = createOctopusButton("Start", bigButton);
    start.setAction(new StartOctopusGenerator());
    JButton stop = createOctopusButton("Stop", bigButton);
    stop.setAction(new StopOctopusGenerator());
    generatorOptionsDown.add(start);
    generatorOptionsDown.add(stop);

    //generatorOptions
    JSplitPane generatorOptions = new JSplitPane(JSplitPane.VERTICAL_SPLIT, true,
        generatorOptionsUp, generatorOptionsDown);
    generatorOptions.setOneTouchExpandable(true);
    generatorOptions.setDividerLocation(560);

    JSplitPane generatorInputData = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, true,
        generatorOptions, octopusGeneratorData);

    //advanced panel
    JPanel pathToConfPanel = new JPanel();
    pathToConfPanel.setLayout(new BoxLayout(pathToConfPanel, BoxLayout.X_AXIS));
    pathToConfPanel.setBorder(setTitleOfBorder("Advanced Options", loweredBorder));
    JLabel strPathToConf = createOctopusLabel(PATH_TO_CONF_IN_JAR, smallComponent);
    JTextField pathToConf = createOctopusTextField(PATH_TO_CONF_IN_JAR, veryBigComponent);
    pathToConfPanel.add(strPathToConf);
    pathToConfPanel.add(pathToConf);

    JPanel mainPathToConfPanel = new JPanel();
    mainPathToConfPanel.setLayout(new BoxLayout(mainPathToConfPanel, BoxLayout.X_AXIS));
    mainPathToConfPanel.add(pathToConfPanel);
    mainPathToConfPanel.add(Box.createHorizontalGlue());

    advancedPanel.setLayout(new BoxLayout(advancedPanel, BoxLayout.Y_AXIS));
    advancedPanel.add(Box.createRigidArea(new Dimension(0, 15)));
    advancedPanel.add(mainPathToConfPanel);

    //sourcePanel
    JPanel sourcePanel = new JPanel();
    sourcePanel.setLayout(new BoxLayout(sourcePanel, BoxLayout.Y_AXIS));
    //sourceType
    JLabel strSourceType = createOctopusLabel(SOURCE_TYPE, bigComponent);
    JComboBox sourceType = createOctopusCombobox(SOURCE_TYPE, bigComponent);
    //sourceUrl
    JLabel strSourceUrl = createOctopusLabel(SOURCE_DATABASE, bigComponent);
    JTextField sourceUrl = createOctopusTextField(SOURCE_DATABASE, bigComponent);
    //sourceDriverName
    JLabel strSourceDriverName = createOctopusLabel(SOURCE_DRIVER_NAME, bigComponent);
    JComboBox sourceDriverName = createOctopusCombobox(SOURCE_DRIVER_NAME, bigComponent);
    //sourceUser
    JLabel strSourceUser = createOctopusLabel(SOURCE_USER, bigComponent);
    JTextField sourceUser = createOctopusTextField(SOURCE_USER, bigComponent);
    //sourcePassword
    JLabel strSourcePassword = createOctopusLabel(SOURCE_PASSWORD, bigComponent);
    JTextField sourcePassword = createOctopusTextField(SOURCE_PASSWORD, bigComponent);
    //doml
    JLabel strDomlUrl = createOctopusLabel(DOML_PATH, bigComponent);
    JTextField domlUrl = createOctopusTextField(DOML_PATH, bigPlusButton);
    JButton domlButton=createOctopusButton("doml url button",new Dimension(20,20));
    domlButton.setAction(new BrowseAction_DOML());

    ImageIcon icon = new ImageIcon(getClass().getClassLoader().getResource(
        "org/webdocwf/util/loader/" +
        "wizard/images/database.gif"));
    JLabel sourceLabel = new JLabel("JDBC Source Database", icon, SwingConstants.RIGHT);

    sourcePanel.add(createJDBCRow(sourceLabel,null));
    sourcePanel.add(Box.createRigidArea(new Dimension(0, 10)));
    sourcePanel.add(createJDBCRow(strSourceType,null));
    sourcePanel.add(createJDBCRow(sourceType,null));
    sourcePanel.add(createJDBCRow(strSourceUrl,null));
    sourcePanel.add(createJDBCRow(sourceUrl,null));
    sourcePanel.add(createJDBCRow(strDomlUrl,null));
    sourcePanel.add(createJDBCRow(domlUrl,domlButton));
    sourcePanel.add(createJDBCRow(strSourceDriverName,null));
    sourcePanel.add(createJDBCRow(sourceDriverName,null));
    sourcePanel.add(createJDBCRow(strSourceUser,null));
    sourcePanel.add(createJDBCRow(sourceUser,null));
    sourcePanel.add(createJDBCRow(strSourcePassword,null));
    sourcePanel.add(createJDBCRow(sourcePassword,null));

    sourcePanel.setBorder(setTitleOfBorder("", bevelBorder));

    //targetPanel
    JPanel targetPanel = new JPanel();
    targetPanel.setLayout(new BoxLayout(targetPanel, BoxLayout.Y_AXIS));
    //targetType
    JLabel strTargetType = createOctopusLabel(TARGET_TYPE, bigComponent);
    JComboBox targetType = createOctopusCombobox(TARGET_TYPE, bigComponent);
    //targetUrl
    JLabel strTargetUrl = createOctopusLabel(TARGET_DATABASE, bigComponent);
    JTextField targetUrl = createOctopusTextField(TARGET_DATABASE, bigComponent);
    //targetDriverName
    JLabel strTargetDriverName = createOctopusLabel(TARGET_DRIVER_NAME, bigComponent);
    JComboBox targetDriverName = createOctopusCombobox(TARGET_DRIVER_NAME, bigComponent);
    //targetUser
    JLabel strTargetUser = createOctopusLabel(TARGET_USER, bigComponent);
    JTextField targetUser = createOctopusTextField(TARGET_USER, bigComponent);
    //targetPassword
    JLabel strTargetPassword = createOctopusLabel(TARGET_PASSWORD, bigComponent);
    JTextField targetPassword = createOctopusTextField(TARGET_PASSWORD, bigComponent);

    JLabel strTargetDoml = createOctopusLabel("Doml URL", bigComponent);
    String msg = "Doml file will be placed in output directory";
    JTextField targetDoml = createOctopusTextField("Doml URL target", bigComponent);
    targetDoml.setText(msg);
    targetDoml.setEditable(false);

    ImageIcon icon2 = new ImageIcon(getClass().getClassLoader().getResource(
        "org/webdocwf/util/loader/" +
        "wizard/images/database2.gif"));
    JLabel targetLabel = new JLabel("JDBC Target Database", icon2, SwingConstants.RIGHT);

    targetPanel.add(createJDBCRow(targetLabel,null));
    targetPanel.add(Box.createRigidArea(new Dimension(0, 10)));
    targetPanel.add(createJDBCRow(strTargetType,null));
    targetPanel.add(createJDBCRow(targetType,null));
    targetPanel.add(createJDBCRow(strTargetUrl,null));
    targetPanel.add(createJDBCRow(targetUrl,null));
    targetPanel.add(createJDBCRow(strTargetDoml,null));
    targetPanel.add(createJDBCRow(targetDoml,null));
    targetPanel.add(createJDBCRow(strTargetDriverName,null));
    targetPanel.add(createJDBCRow(targetDriverName,null));
    targetPanel.add(createJDBCRow(strTargetUser,null));
    targetPanel.add(createJDBCRow(targetUser,null));
    targetPanel.add(createJDBCRow(strTargetPassword,null));
    targetPanel.add(createJDBCRow(targetPassword,null));

    targetPanel.setBorder(setTitleOfBorder("", bevelBorder));

    JPanel JDBCPanel = new JPanel();
    JDBCPanel.setLayout(new BoxLayout(JDBCPanel, BoxLayout.X_AXIS));
    JDBCPanel.add(sourcePanel);
    JDBCPanel.add(targetPanel);

    JPanel JDBCMainPanel = new JPanel();
    JDBCMainPanel.setLayout(new BoxLayout(JDBCMainPanel, BoxLayout.X_AXIS));
    JDBCMainPanel.add(JDBCPanel);
    JDBCMainPanel.add(Box.createHorizontalGlue());

    //value mode panel
    JPanel valuModePanel = new JPanel();
    valuModePanel.setLayout(new BoxLayout(valuModePanel, BoxLayout.X_AXIS));
    valuModePanel.setBorder(setTitleOfBorder("Value mode", loweredBorder));
    JLabel strValueMode = createOctopusLabel(VALUE_MODE, smallComponent);
    JComboBox valueMode = createOctopusCombobox(VALUE_MODE, veryBigComponent);
    valuModePanel.add(strValueMode);
    valuModePanel.add(valueMode);

    JPanel mainValueModePanel = new JPanel();
    mainValueModePanel.setLayout(new BoxLayout(mainValueModePanel, BoxLayout.X_AXIS));
    mainValueModePanel.add(valuModePanel);
    mainValueModePanel.add(Box.createHorizontalGlue());

    //generatorOutput panel
    JPanel generatorOutputPanel = new JPanel();
    generatorOutputPanel.setLayout(new BoxLayout(generatorOutputPanel, BoxLayout.X_AXIS));
    JPanel generatorOutputInnerPanel = new JPanel();
    JButton browseGeneratorOutput = createOctopusButton("O", new Dimension(20, 20));
    browseGeneratorOutput.setAction(new BrowseAction_GO());

    generatorOutputInnerPanel.setLayout(new BoxLayout(generatorOutputInnerPanel, BoxLayout.X_AXIS));
    generatorOutputInnerPanel.setBorder(setTitleOfBorder("Generator Output", loweredBorder));
    JLabel strGeneratorOutput = createOctopusLabel(GENERATOR_OUTPUT, smallComponent);
    generatorOutput = createOctopusTextField(GENERATOR_OUTPUT, veryBigPlusButton);
    generatorOutputInnerPanel.add(strGeneratorOutput);
    generatorOutputInnerPanel.add(generatorOutput);
    generatorOutputInnerPanel.add(browseGeneratorOutput);

    generatorOutputPanel.add(generatorOutputInnerPanel);
    generatorOutputPanel.add(Box.createHorizontalGlue());

    //includetablelist panel
    JPanel includeTableListPanel = new JPanel();
    includeTableListPanel.setLayout(new BoxLayout(includeTableListPanel, BoxLayout.X_AXIS));
    JPanel includeTableListInnerPanel = new JPanel();
    includeTableListInnerPanel.setLayout(new BoxLayout(includeTableListInnerPanel, BoxLayout.X_AXIS));
    includeTableListInnerPanel.setBorder(setTitleOfBorder("Tables List", loweredBorder));
    JLabel strIncludeTableList = createOctopusLabel(INCLUDE_TABLE_LIST, smallComponent);
    JTextField includeTableList = createOctopusTextField(INCLUDE_TABLE_LIST, veryBigComponent);
    includeTableListInnerPanel.add(strIncludeTableList);
    includeTableListInnerPanel.add(includeTableList);

    includeTableListPanel.add(includeTableListInnerPanel);
    includeTableListPanel.add(Box.createHorizontalGlue());

    //additinal classpaths panel
    JPanel addPathsPanel = new JPanel();
    addPathsPanel.setLayout(new BoxLayout(addPathsPanel, BoxLayout.X_AXIS));
    JPanel addPathsInnerPanel = new JPanel();
    JButton browseAdditionalClass = createOctopusButton("O", new Dimension(20, 20));
    browseAdditionalClass.setAction(new BrowseAction_AC());
    addPathsInnerPanel.setLayout(new BoxLayout(addPathsInnerPanel, BoxLayout.X_AXIS));
    addPathsInnerPanel.setBorder(setTitleOfBorder("Add new drivers", loweredBorder));
    JLabel strAddPaths = createOctopusLabel(ADDITIONAL_PATHS, smallComponent);
    addPaths = createOctopusTextField(ADDITIONAL_PATHS, veryBigPlusButton);
    addPathsInnerPanel.add(strAddPaths);
    addPathsInnerPanel.add(addPaths);
    addPathsInnerPanel.add(browseAdditionalClass);

    addPathsPanel.add(addPathsInnerPanel);
    addPathsPanel.add(Box.createHorizontalGlue());

    JPanel commonOptionsPanel = new JPanel();
    JPanel commonOptionsMainPanel = new JPanel();
    commonOptionsPanel.setLayout(new BoxLayout(commonOptionsPanel, BoxLayout.Y_AXIS));
    commonOptionsMainPanel.setLayout(new BoxLayout(commonOptionsMainPanel, BoxLayout.X_AXIS));
    commonOptionsPanel.add(mainValueModePanel);
    commonOptionsPanel.add(generatorOutputPanel);
    commonOptionsPanel.add(includeTableListPanel);
    commonOptionsPanel.add(addPathsPanel);

    commonOptionsMainPanel.add(commonOptionsPanel);
    commonOptionsMainPanel.add(Box.createHorizontalGlue());

    commonPanel.setLayout(new BoxLayout(commonPanel, BoxLayout.Y_AXIS));
    commonPanel.add(JDBCMainPanel);
    commonPanel.add(commonOptionsMainPanel);
    commonPanel.add(Box.createVerticalGlue());

    JPanel outputMode = new JPanel();
    outputMode.setLayout(new BoxLayout(outputMode, BoxLayout.X_AXIS));
    outputMode.setBorder(setTitleOfBorder("Output Mode", loweredBorder));
    sqlFiles = new JCheckBox(GENERATE_SQL);
    sqlFiles.setSelected(true);
    xmlFiles = new JCheckBox(GENERATE_XML);
    xmlFiles.setSelected(true);
    domlFile = new JCheckBox(GENERATE_DOML);
    outputMode.add(sqlFiles);
    outputMode.add(xmlFiles);
    outputMode.add(domlFile);

    sqlFiles.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        if(sqlFiles.isSelected()) {
          createTables.setEnabled(true);
          createTables.setSelected(true);
          dropTables.setEnabled(true);
          dropTables.setSelected(true);
          createPK.setEnabled(true);
          createPK.setSelected(true);
          createFK.setEnabled(true);
          createFK.setSelected(true);
          dropFK.setEnabled(true);
          dropFK.setSelected(true);
          createIn.setEnabled(true);
          createIn.setSelected(true);
          createSQLForAll.setEnabled(true);
          createSQLForAll.setSelected(false);
        } else {
          createTables.setSelected(false);
          createTables.setEnabled(false);
          dropTables.setEnabled(false);
          dropTables.setSelected(false);
          createPK.setEnabled(false);
          createPK.setSelected(false);
          createFK.setEnabled(false);
          createFK.setSelected(false);
          dropFK.setEnabled(false);
          dropFK.setSelected(false);
          createIn.setEnabled(false);
          createIn.setSelected(false);
          createSQLForAll.setEnabled(false);
          createSQLForAll.setSelected(false);
        }
      }
    });

    xmlFiles.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        if(xmlFiles.isSelected()) {
          optimizedMode.setEnabled(true);
          optimizedMode.setSelected(false);
          fullMode.setEnabled(true);
          fullMode.setSelected(true);
        } else {
          optimizedMode.setEnabled(false);
          optimizedMode.setSelected(false);
          fullMode.setEnabled(false);
          fullMode.setSelected(false);
        }
      }
    });

    domlFile.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        if(domlFile.isSelected()) {
          packageField.setEditable(true);
          packageField.setText("");
        } else {
          packageField.setText("");
          packageField.setEditable(false);

        }
      }
    });

    JPanel mainOutputMode = new JPanel();
    mainOutputMode.setLayout(new BoxLayout(mainOutputMode, BoxLayout.X_AXIS));
    mainOutputMode.add(outputMode);
    mainOutputMode.add(Box.createHorizontalGlue());

    createTables = new JCheckBox(CREATE_TABLE);
    createTables.setSelected(true);
    createPK = new JCheckBox(CREATE_PRIMARY_KEYS);
    createPK.setSelected(true);
    createFK = new JCheckBox(CREATE_FOREIGN_KEYS);
    createFK.setSelected(true);
    createIn = new JCheckBox(CREATE_INDEXES);
    createIn.setSelected(true);
    dropTables = new JCheckBox(DROP_TABLE);
    dropTables.setSelected(true);
    dropFK = new JCheckBox(DROP_FOREIGN_KEYS);
    dropFK.setSelected(true);
    createSQLForAll = new JCheckBox(CREATE_SQL_FOR_ALL_VENDORS);

    JPanel sqlOptionsPanel1 = new JPanel();
    sqlOptionsPanel1.setLayout(new BoxLayout(sqlOptionsPanel1, BoxLayout.Y_AXIS));
    sqlOptionsPanel1.add(dropTables);
    sqlOptionsPanel1.add(createTables);
    sqlOptionsPanel1.add(createPK);

    JPanel sqlOptionsPanel2 = new JPanel();
    sqlOptionsPanel2.setLayout(new BoxLayout(sqlOptionsPanel2, BoxLayout.Y_AXIS));
    sqlOptionsPanel2.add(dropFK);
    sqlOptionsPanel2.add(createFK);
    sqlOptionsPanel2.add(createIn);

    JPanel sqlOptionsPanel3 = new JPanel();
    sqlOptionsPanel3.setLayout(new BoxLayout(sqlOptionsPanel3, BoxLayout.Y_AXIS));
    sqlOptionsPanel3.add(createSQLForAll);

    JPanel sqlOptionsPanel = new JPanel();
    sqlOptionsPanel.setLayout(new BoxLayout(sqlOptionsPanel, BoxLayout.X_AXIS));
    sqlOptionsPanel.setBorder(setTitleOfBorder("SQL Options", loweredBorder));
    sqlOptionsPanel.add(sqlOptionsPanel1);
    sqlOptionsPanel.add(sqlOptionsPanel2);
    sqlOptionsPanel.add(sqlOptionsPanel3);

    JPanel mainSqlOptionsPanel = new JPanel();
    mainSqlOptionsPanel.setLayout(new BoxLayout(mainSqlOptionsPanel, BoxLayout.X_AXIS));
    mainSqlOptionsPanel.add(sqlOptionsPanel);
    mainSqlOptionsPanel.add(Box.createHorizontalGlue());

    JPanel xmlOptionsPanel = new JPanel();
    xmlOptionsPanel.setLayout(new BoxLayout(xmlOptionsPanel, BoxLayout.X_AXIS));
    optimizedMode = new JRadioButton(OPTIMIZED_MODE);
    fullMode = new JRadioButton(FULL_MODE);
    fullMode.setSelected(true);

    optimizedMode.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        if(optimizedMode.isSelected()) {
          fullMode.setSelected(false);
        } else {
          fullMode.setSelected(true);
        }
      }
    });

    fullMode.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        if(fullMode.isSelected()) {
          optimizedMode.setSelected(false);
        } else {
          optimizedMode.setSelected(true);
        }
      }
    });

    xmlOptionsPanel.setBorder(setTitleOfBorder("XML Options", loweredBorder));
    xmlOptionsPanel.add(optimizedMode);
    xmlOptionsPanel.add(fullMode);

    JPanel mainXmlOptionsPanel = new JPanel();
    mainXmlOptionsPanel.setLayout(new BoxLayout(mainXmlOptionsPanel, BoxLayout.X_AXIS));
    mainXmlOptionsPanel.add(xmlOptionsPanel);
    mainXmlOptionsPanel.add(Box.createHorizontalGlue());

    JPanel packagePanel = new JPanel();
    packagePanel.setLayout(new BoxLayout(packagePanel, BoxLayout.X_AXIS));
    packagePanel.setBorder(setTitleOfBorder("Package name for doml file", loweredBorder));
    packageField = createOctopusTextField(PACKAGE_NAME, veryBigComponent);
    packageField.setEditable(false);
    JLabel strPackageField = createOctopusLabel(PACKAGE_NAME, smallComponent);
    packagePanel.add(strPackageField);
    packagePanel.add(packageField);

    JPanel mainPackagePanel = new JPanel();
    mainPackagePanel.setLayout(new BoxLayout(mainPackagePanel, BoxLayout.X_AXIS));
    mainPackagePanel.add(packagePanel);
    mainPackagePanel.add(Box.createHorizontalGlue());

    //output options panel
    outputOptions.setLayout(new BoxLayout(outputOptions, BoxLayout.Y_AXIS));

    outputOptions.add(Box.createRigidArea(new Dimension(0, 10)));
    outputOptions.add(mainOutputMode);
    outputOptions.add(Box.createRigidArea(new Dimension(0, 10)));
    outputOptions.add(mainSqlOptionsPanel);
    outputOptions.add(Box.createRigidArea(new Dimension(0, 10)));
    outputOptions.add(mainXmlOptionsPanel);
    outputOptions.add(Box.createRigidArea(new Dimension(0, 10)));
    outputOptions.add(mainPackagePanel);

    // output panel
    JPanel textAreaPanel = new JPanel();
    textAreaPanel.setLayout(new BoxLayout(textAreaPanel, BoxLayout.X_AXIS));
    JPanel areaOptionPanel = new JPanel();
    areaOptionPanel.setLayout(new BoxLayout(areaOptionPanel, BoxLayout.Y_AXIS));
    traceArea = new JTextArea(18, 130);
    traceArea.setLineWrap(true);
    traceArea.setEditable(false);
    traceArea.setBorder(BorderFactory.createEtchedBorder(EtchedBorder.RAISED));
    JScrollPane scrollPane = new JScrollPane(traceArea,
        ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
        ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS);

    scrollPane.setBorder(setTitleOfBorder("Log Octopus Generator output ... ", loweredBorder));
    JButton fullScreen = createOctopusButton("Full Screen", new Dimension(25, 25));
    fullScreen.setAction(new FullScreenAction());
    JButton normalScreen = createOctopusButton("Normal Screen", new Dimension(25, 25));
    normalScreen.setAction(new NormalScreenAction());
    JButton saveScreen = createOctopusButton("Save Trace", new Dimension(25, 25));
    saveScreen.setAction(new SaveTraceAction());
    JButton clearTrace = createOctopusButton("Clear Trace", new Dimension(25, 25));
    clearTrace.setAction(new ClearTraceAction());

    areaOptionPanel.add(fullScreen);
    areaOptionPanel.add(normalScreen);
    areaOptionPanel.add(saveScreen);
    areaOptionPanel.add(clearTrace);
    areaOptionPanel.setBorder(BorderFactory.createEtchedBorder(EtchedBorder.LOWERED));

    JPanel areaOptionMainPanel = new JPanel(new BorderLayout());
    areaOptionMainPanel.add(areaOptionPanel, BorderLayout.PAGE_START);

    textAreaPanel.add(areaOptionMainPanel);
    textAreaPanel.add(scrollPane);
    main = new JSplitPane(JSplitPane.VERTICAL_SPLIT, true, generatorInputData,
        textAreaPanel);
    main.setOneTouchExpandable(true);
    main.setDividerLocation(650);

    //setting all parameters into hash table
    //source
    fields.put(SOURCE_TYPE, sourceType);
    fields.put(SOURCE_DATABASE, sourceUrl);
    fields.put(DOML_PATH, domlUrl);
    fields.put(SOURCE_DRIVER_NAME, sourceDriverName);
    fields.put(SOURCE_USER, sourceUser);
    fields.put(SOURCE_PASSWORD, sourcePassword);
    //target
    fields.put(TARGET_TYPE, targetType);
    fields.put(TARGET_DATABASE, targetUrl);
    fields.put(TARGET_DRIVER_NAME, targetDriverName);
    fields.put(TARGET_USER, targetUser);
    fields.put(TARGET_PASSWORD, targetPassword);

    //copy mode
    fields.put(VALUE_MODE, valueMode);

    fields.put(GENERATOR_OUTPUT, generatorOutput);
    fields.put(ADDITIONAL_PATHS, addPaths);
    fields.put(INCLUDE_TABLE_LIST, includeTableList);

    //sql statements
    fields.put(GENERATE_SQL, sqlFiles);
    fields.put(CREATE_TABLE, createTables);
    fields.put(CREATE_PRIMARY_KEYS, createPK);
    fields.put(CREATE_FOREIGN_KEYS, createFK);
    fields.put(CREATE_INDEXES, createIn);
    fields.put(DROP_TABLE, dropTables);
    fields.put(DROP_FOREIGN_KEYS, dropFK);
    fields.put(CREATE_SQL_FOR_ALL_VENDORS, createSQLForAll);

    //xml options
    fields.put(GENERATE_XML, xmlFiles);
    fields.put(FULL_MODE, fullMode);
    fields.put(OPTIMIZED_MODE, optimizedMode);

    //doml options
    fields.put(GENERATE_DOML, domlFile);
    fields.put(PACKAGE_NAME, packageField);

    //advanced
    fields.put(PATH_TO_CONF_IN_JAR, pathToConf);

    Container container = getContentPane();
    container.setLayout(new BoxLayout(container, BoxLayout.X_AXIS));
    container.add(main);
    setBounds(0, 0, 970, 680);
  }

  private JPanel createJDBCRow(JComponent jc1, JComponent jc2){
    JPanel jp = new JPanel();
    jp.setLayout(new BoxLayout(jp, BoxLayout.X_AXIS));
    jp.add(jc1);
    if(jc2!=null)
      jp.add(jc2);

    jp.add(Box.createHorizontalGlue());
    return jp;
  }

  private Border setTitleOfBorder(String title, Border border) {
    Border inb = BorderFactory.createTitledBorder(border, title);
    return inb;
  }

  private JButton createOctopusButton(String componentName, Dimension dimension) {

    JButton button = new JButton();
    if(!componentName.equalsIgnoreCase(""))
      button.setText(componentName);

    button.setAlignmentX(Component.LEFT_ALIGNMENT);
    button.setAlignmentY(Component.CENTER_ALIGNMENT);
    button.setMinimumSize(new Dimension(dimension));
    button.setMaximumSize(new Dimension(dimension));
    button.setPreferredSize(new Dimension(dimension));

    return button;
  }

  private JComboBox createOctopusCombobox(String componentName, Dimension dimension) {

    JComboBox comboBox = new JComboBox();
    comboBox.setName(componentName);
    comboBox.setAlignmentX(Component.LEFT_ALIGNMENT);
    comboBox.setAlignmentY(Component.CENTER_ALIGNMENT);
    comboBox.setMinimumSize(new Dimension(dimension));
    comboBox.setMaximumSize(new Dimension(dimension));
    comboBox.setPreferredSize(new Dimension(dimension));

    return comboBox;
  }

  private JLabel createOctopusLabel(String componentName, Dimension dimension) {

    JLabel label = new JLabel();
    label.setText(componentName);
    label.setAlignmentX(Component.LEFT_ALIGNMENT);
    label.setAlignmentY(Component.CENTER_ALIGNMENT);
    label.setMinimumSize(new Dimension(dimension));
    label.setMaximumSize(new Dimension(dimension));
    label.setPreferredSize(new Dimension(dimension));

    return label;
  }

  private JTextField createOctopusTextField(String componentName, Dimension dimension) {

    JTextField textField = new JTextField();
    textField.setName(componentName);
    textField.setAlignmentX(Component.LEFT_ALIGNMENT);
    textField.setAlignmentY(Component.CENTER_ALIGNMENT);
    textField.setMinimumSize(new Dimension(dimension));
    textField.setMaximumSize(new Dimension(dimension));
    textField.setPreferredSize(new Dimension(dimension));

    return textField;
  }

  public void setOctopusGeneratorInit(OctopusGeneratorData initData, String confJarStructure) {
    this.initData = initData;
    setField(SOURCE_TYPE, initData.getSourceType(), "box");
    setField(SOURCE_DRIVER_NAME, initData.getSourceDriverName(), "box");
    setField(SOURCE_DATABASE, initData.getSourceDatabase(), "label");

    setField(TARGET_TYPE, initData.getTargetType(), "box");
    setField(TARGET_DRIVER_NAME, initData.getTargetDriverName(), "box");
    setField(TARGET_DATABASE, initData.getTargetDatabase(), "label");

    setField(VALUE_MODE, initData.getValueMode(), "box");

  }

  public OctopusGeneratorData getOctopusGeneratorInit() throws Exception {

    initData.setSourceType(getField(SOURCE_TYPE, "box"));
    initData.setTargetType(getField(TARGET_TYPE, "box"));
    initData.setSourceDatabase(getField(SOURCE_DATABASE, "label"));
    initData.setTargetDatabase(getField(TARGET_DATABASE, "label"));
    initData.setSourceUser(getField(SOURCE_USER, "label"));
    initData.setSourcePassword(getField(SOURCE_PASSWORD, "label"));
    initData.setTargetUser(getField(TARGET_USER, "label"));
    initData.setTargetPassword(getField(TARGET_PASSWORD, "label"));
    initData.setValueMode(getField(VALUE_MODE, "box"));
    initData.setGeneratorOutput(getField(GENERATOR_OUTPUT, "label"));
    initData.setDomlPath(getField(DOML_PATH, "label"));
    initData.setPackageName(getField(PACKAGE_NAME, "label"));
    initData.setSourceDriverName(getField(SOURCE_DRIVER_NAME, "box"));
    initData.setTargetDriverName(getField(TARGET_DRIVER_NAME, "box"));
    initData.setAdditionalPaths(getField(ADDITIONAL_PATHS, "label"));
    initData.setSqlStmtDropTable(getField(DROP_TABLE, "checkBox"));
    initData.setSqlStmtDropIntegrity(getField(DROP_FOREIGN_KEYS, "checkBox"));
    initData.setSqlStmtCreateTable(getField(CREATE_TABLE, "checkBox"));
    initData.setSqlStmtCreatePK(getField(CREATE_PRIMARY_KEYS, "checkBox"));
    initData.setSqlStmtCreateFK(getField(CREATE_FOREIGN_KEYS, "checkBox"));
    initData.setSqlStmtCreateIndex(getField(CREATE_INDEXES, "checkBox"));
    initData.setSqlStmtForAllVendors(getField(CREATE_SQL_FOR_ALL_VENDORS, "checkBox"));
    initData.setSqlGenerate(getField(GENERATE_SQL, "checkBox"));
    initData.setXmlGenerate(getField(GENERATE_XML, "checkBox"));
    initData.setDomlGenerate(getField(GENERATE_DOML, "checkBox"));
    if(getField(FULL_MODE, "radioButton").equalsIgnoreCase("true"))
      initData.setFullMode("true");
    else
      initData.setFullMode("false");
    initData.setIncludeTableList(getField(INCLUDE_TABLE_LIST, "label"));
    initData.setConfJarStructure(getField(PATH_TO_CONF_IN_JAR, "label"));
    return initData;
  }

  private String getField(String fieldName, String type) {
    if(type.equalsIgnoreCase("label")) {
      JTextField field = (JTextField)fields.get(fieldName);
      return field.getText().trim();
    } else if(type.startsWith("checkBox")) {
      JCheckBox field = (JCheckBox)fields.get(fieldName);
      if(field.isSelected() == true)
        return "true";
      else
        return "false";
    } else if(type.startsWith("radioButton")) {
      JRadioButton field = (JRadioButton)fields.get(fieldName);
      if(field.isSelected() == true)
        return "true";
      else
        return "false";
    } else {
      JComboBox field = (JComboBox)fields.get(fieldName);
      return field.getSelectedItem().toString();

    }
  }

  private void setField(String fieldName, String value, String type) {
    if(!type.equalsIgnoreCase("box")) {
      JTextField field = (JTextField)fields.get(fieldName);
      field.setText(value);
    } else {
      JComboBox field = (JComboBox)fields.get(fieldName);
      if(fieldName.equalsIgnoreCase(SOURCE_TYPE)) {
        for(int i = 0; i < OctopusGeneratorData.getSourceDatabaseTypes().length; i++) {
          field.addItem(OctopusGeneratorData.getSourceDatabaseTypes()[i]);
        }
      } else if(fieldName.equalsIgnoreCase(TARGET_TYPE)) {
        for(int i = 0; i < OctopusGeneratorData.getTargetDatabaseTypes().length; i++) {
          field.addItem(OctopusGeneratorData.getTargetDatabaseTypes()[i]);
        }
      } else if(fieldName.equalsIgnoreCase(SOURCE_DRIVER_NAME)) {
        for(int i = 0; i < OctopusGeneratorData.getSourceDriverNames().length; i++) {
          field.addItem(OctopusGeneratorData.getSourceDriverNames()[i]);
        }
      } else if(fieldName.equalsIgnoreCase(TARGET_DRIVER_NAME)) {
        for(int i = 0; i < OctopusGeneratorData.getTargetDriverNames().length; i++) {
          field.addItem(OctopusGeneratorData.getTargetDriverNames()[i]);
        }
      } else if(fieldName.equalsIgnoreCase(VALUE_MODE)) {
        for(int i = 0; i < OctopusGeneratorData.getValueModes().length; i++) {
          field.addItem(OctopusGeneratorData.getValueModes()[i]);
        }
      }
    }
  }

  private class FullScreenAction
      extends AbstractAction {

    /**
     * This method starts the LoaderGenerator application
     */
    public FullScreenAction() {

      putValue(SMALL_ICON,
          new ImageIcon(getClass().getClassLoader().getResource("org/webdocwf/util/loader/" +
          "wizard/images/Host16.gif")));
      putValue(SHORT_DESCRIPTION, "Full Screen");
      putValue(LONG_DESCRIPTION, "Set Trace to Full Screen");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('F',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(MNEMONIC_KEY, new Integer('F'));
    }

    /**
     * This method check if the action is performed (event key pressed)
     * @param e is event
     */
    public void actionPerformed(ActionEvent e) {
      main.setDividerLocation(0);
    }
  }

  private class NormalScreenAction
      extends AbstractAction {

    /**
     * This method starts the LoaderGenerator application
     */
    public NormalScreenAction() {

      putValue(SMALL_ICON,
          new ImageIcon(getClass().getClassLoader().getResource("org/webdocwf/util/loader/" +
          "wizard/images/Unhost16.gif")));
      putValue(SHORT_DESCRIPTION, "Normal Screen");
      putValue(LONG_DESCRIPTION, "Back to normal screen");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('N',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(MNEMONIC_KEY, new Integer('N'));
    }

    /**
     * This method check if the action is performed (event key pressed)
     * @param e is event
     */
    public void actionPerformed(ActionEvent e) {
      main.setDividerLocation(510);
    }
  }

  private class SaveTraceAction
      extends AbstractAction {

    /**
     * This method starts the LoaderGenerator application
     */
    public SaveTraceAction() {

      putValue(SMALL_ICON,
          new ImageIcon(getClass().getClassLoader().getResource("org/webdocwf/util/loader/" +
          "wizard/images/Save16.gif")));
      putValue(SHORT_DESCRIPTION, "Save Trace");
      putValue(LONG_DESCRIPTION, "Save Trace to file");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('S',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(MNEMONIC_KEY, new Integer('S'));
    }

    /**
     * This method check if the action is performed (event key pressed)
     * @param e is event
     */
    public void actionPerformed(ActionEvent e) {
      JFileChooser fc = new JFileChooser();
      fc.setDialogTitle("Save Octopus log ...");
      int returnVal = fc.showSaveDialog(null);
      if(returnVal == JFileChooser.APPROVE_OPTION) {
        File file = fc.getSelectedFile();
        String text = traceArea.getText();
        try {
          Writer out = new BufferedWriter(new FileWriter(file, false));
          out.write(text);
          out.close();
        }
        catch(Exception ex) {
          ex.printStackTrace();
        }

      } else {
      //do nothing
      }
    }
  }

  private class ClearTraceAction
      extends AbstractAction {

    /**
     * This method starts the LoaderGenerator application
     */
    public ClearTraceAction() {

      putValue(SMALL_ICON,
          new ImageIcon(getClass().getClassLoader().getResource("org/webdocwf/util/loader/" +
          "wizard/images/Delete16.gif")));
      putValue(SHORT_DESCRIPTION, "Clear Trace");
      putValue(LONG_DESCRIPTION, "Clear Trace");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('L',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(MNEMONIC_KEY, new Integer('L'));
    }

    /**
     * This method check if the action is performed (event key pressed)
     * @param e is event
     */
    public void actionPerformed(ActionEvent e) {
      traceArea.setText("");
    }
  }

  private class BrowseAction_GO
      extends AbstractAction {

    /**
     * This method stop the LoaderGenerator application
     */
    public BrowseAction_GO() {
      putValue(SMALL_ICON,
          new ImageIcon(getClass().getClassLoader().
          getResource("org/webdocwf/util/loader/" +
          "wizard/images/Open16.gif")));
      putValue(SHORT_DESCRIPTION, "Browse for Generator output directory");
      putValue(LONG_DESCRIPTION, "Browse for Generator output directory");
      putValue(MNEMONIC_KEY, new Integer('B'));
    }

    /**
     * This method check if the action is performed (event key pressed)
     * @param e is event
     */
    public void actionPerformed(ActionEvent e) {
      JFileChooser chooser = null;
      File choice = null;
      File current = new File(System.getProperty("user.dir"));
      chooser = new JFileChooser(current);
      chooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
      chooser.setFileFilter((javax.swing.filechooser.FileFilter)new DirectoryFilter());
      chooser.setDialogTitle("Select Generator Output Directory");
      chooser.setApproveButtonText("OK");
      String strFieldText = "";

      chooser.setCurrentDirectory(new File(strFieldText));
      int v = chooser.showOpenDialog(desktop);
      desktop.requestFocus();

      switch(v) {
        case JFileChooser.APPROVE_OPTION:
          if(chooser.getSelectedFile() != null) {
            if(chooser.getSelectedFile().exists()) {
              choice = chooser.getSelectedFile();
            } else {
              File parentFile = new File(chooser.getSelectedFile().getParent());
              choice = parentFile;
            }
            generatorOutput.setText(choice.getPath());
          }
          break;

        case JFileChooser.CANCEL_OPTION:
        case JFileChooser.ERROR_OPTION:

      }
    }
  }

  //additional paths
  private class BrowseAction_AC
      extends AbstractAction {

    /**
     * This method stop the LoaderGenerator application
     */
    public BrowseAction_AC() {
      putValue(SMALL_ICON,
          new ImageIcon(getClass().getClassLoader().
          getResource("org/webdocwf/util/loader/" +
          "wizard/images/Open16.gif")));
      putValue(SHORT_DESCRIPTION, "Add .jar files");
      putValue(LONG_DESCRIPTION, "Add .jar (jdbc) files to system classpath");
      putValue(MNEMONIC_KEY, new Integer('B'));
    }

    /**
     * This method check if the action is performed (event key pressed)
     * @param e is event
     */
    public void actionPerformed(ActionEvent e) {
      JFileChooser chooser = null;
      File choice = null;
      File current = new File(System.getProperty("user.dir"));
      chooser = new JFileChooser(current);
      chooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
      chooser.setFileFilter((javax.swing.filechooser.FileFilter)new JarFilter());
      chooser.setDialogTitle("Select .jar file");
      chooser.setAcceptAllFileFilterUsed(false);
      String strFieldText = addPaths.getText();

      if(!strFieldText.equalsIgnoreCase(""))
        strFieldText = strFieldText + ";";

      chooser.setCurrentDirectory(new File(strFieldText));
      chooser.setApproveButtonText("OK");
      int v = chooser.showOpenDialog(desktop);

      desktop.requestFocus();
      switch(v) {
        case JFileChooser.APPROVE_OPTION:
          if(chooser.getSelectedFile() != null) {
            if(chooser.getSelectedFile().exists()) {
              choice = chooser.getSelectedFile();
            } else {
              File parentFile = new File(chooser.getSelectedFile().getParent());
              choice = parentFile;
            }
            addPaths.setText(strFieldText + choice.getPath());
          }
          break;

        case JFileChooser.CANCEL_OPTION:
        case JFileChooser.ERROR_OPTION:

          chooser.removeAll();
          chooser = null;
          current = null;

      }
    }
  }

  private class StartOctopusGenerator
      extends AbstractAction {

    /**
     * This method starts the LoaderGenerator application
     */
    public StartOctopusGenerator() {

      putValue(NAME, "Start");
      putValue(SMALL_ICON,
          new ImageIcon(getClass().getClassLoader().getResource("org/webdocwf/util/loader/" +
          "wizard/images/Play16.gif")));
      putValue(SHORT_DESCRIPTION, "Start the OctopusGenerator application");
      putValue(LONG_DESCRIPTION, "Start the OctopusGenerator application");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('R',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(MNEMONIC_KEY, new Integer('R'));
    }

    /**
     * This method check if the action is performed (event key pressed)
     * @param e is event
     */
    public void actionPerformed(ActionEvent e) {
      OctopusGeneratorData initData = null;
      String errorMsg = null;
      main.setDividerLocation(520);
      try {
        initData = getOctopusGeneratorInit();
        traceArea.setText("");
        OctopusGeneratorThread runGenerator = new OctopusGeneratorThread(desktop,
            initData, errorMsg, traceArea);
        runGenerator.start();
      }
      catch(Exception ex) {
        errorMsg = ex.getMessage();
      }
    }
  }

  private class StopOctopusGenerator
      extends AbstractAction {

    /**
     * This method stop the LoaderGenerator application
     */
    public StopOctopusGenerator() {

      putValue(NAME, "Close");
      putValue(SMALL_ICON,
          new ImageIcon(getClass().getClassLoader().getResource("org/webdocwf/util/loader/" +
          "wizard/images/Stop16.gif")));
      putValue(SHORT_DESCRIPTION, "Stop the OctopusGenerator application");
      putValue(LONG_DESCRIPTION, "Stop the OctopusGenerator application");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('T',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(MNEMONIC_KEY, new Integer('T'));
    }

    /**
     * This method check if the action is performed (event key pressed)
     * @param e is event
     */
    public void actionPerformed(ActionEvent e) {
      dispose();

    }
  }

  private class OctopusHelpAction
      extends AbstractAction {

    /**
     * Action which creates new help frame
     */
    public OctopusHelpAction() {
      putValue(NAME, "Help");
      putValue(SMALL_ICON,
          new ImageIcon(getClass().getClassLoader().getResource("org/webdocwf/util/loader/" +
          "wizard/images/Help16.gif")));
      putValue(SHORT_DESCRIPTION, "Help for running the program");
      putValue(LONG_DESCRIPTION, "Help for running the program");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('H',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(MNEMONIC_KEY, new Integer('H'));
    }

    /**
     * Creating event for new windows help frame
     * @param e is creating events
     */
    public void actionPerformed(ActionEvent e) {
      try {
        OctopusGeneratorHelpFrame helpFrame = new OctopusGeneratorHelpFrame();
        helpFrame.setIconImage(new ImageIcon(getClass().getClassLoader().getResource(
            "org/webdocwf/util/loader/" +
            "wizard/images/Enhydra16.gif")).getImage());
        helpFrame.setVisible(true);
      }
      catch(Exception ex) {
        String message = ex.getMessage();
        String message2 = "Check the OCTOPUS_HOME variable!";
        JOptionPane error = new JOptionPane();
        error.showMessageDialog(desktop, message + "\n" + message2, "Error", 0);
        error.setVisible(true);
        System.exit(0);
      }
    }
  }

  private class StartOctopusLoader
      extends AbstractAction {

    /**
     * This method starts the LoaderGenerator application
     */
    public StartOctopusLoader() {

      putValue(NAME, "Loader");
      putValue(SMALL_ICON,
          new ImageIcon(getClass().getClassLoader().getResource("org/webdocwf/util/loader/" +
          "wizard/images/Goto16.gif")));
      putValue(SHORT_DESCRIPTION, "Start the OctopusLoader application");
      putValue(LONG_DESCRIPTION, "Start the OctopusLoader application");
//      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('O',
//          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
//      putValue(MNEMONIC_KEY, new Integer('O'));
    }

    /**
     * This method check if the action is performed (event key pressed)
     * @param e is event
     */
    public void actionPerformed(ActionEvent e) {
      OctopusLoaderFrame octopusLoader = new OctopusLoaderFrame(desktop);
      setDefaultCloseOperation(DISPOSE_ON_CLOSE);
      String confJarStructure = "";
      try {
        octopusLoader.setOctopusLoaderInit(new OctopusLoaderData(), null, confJarStructure);
        desktop.add(octopusLoader);
        octopusLoader.setVisible(true);
      }
      catch(Exception ex) {
        String message = ex.getMessage();
        String message2 = "Check the OCTOPUS_HOME variable!";
        JOptionPane error = new JOptionPane();
        error.showMessageDialog(desktop, message + "\n" + message2, "Error", 0);
        error.setVisible(true);
        System.exit(0);
      }
      //kill the instance of generator
      dispose();
    }
  }

  //doml file
  private class BrowseAction_DOML extends AbstractAction{

    /**
     * This method stop the LoaderGenerator application
     */
    public BrowseAction_DOML() {
//      putValue(NAME, "browse");
      putValue(SMALL_ICON,
               new ImageIcon(getClass().getClassLoader().
                             getResource("org/webdocwf/util/loader/" +
                                         "wizard/images/Open16.gif")));
      putValue(SHORT_DESCRIPTION, "Browse for .doml file");
      putValue(LONG_DESCRIPTION, "Browse for .doml file");
      putValue(MNEMONIC_KEY, new Integer('B'));
    }

    /**
     * This method check if the action is performed (event key pressed)
     * @param e is event
     */
    public void actionPerformed(ActionEvent e) {
      JFileChooser chooser = null;
      File choice = null;
      File current=new File(System.getProperty("user.dir"));
      chooser = new JFileChooser(current);
      chooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
      chooser.setFileFilter( (javax.swing.filechooser.FileFilter)new DomlFilter());
      chooser.setDialogTitle("Select .doml file");
      chooser.setAcceptAllFileFilterUsed(false);
      String strFieldText = "";

      chooser.setCurrentDirectory(new File(strFieldText));
      chooser.setApproveButtonText("OK");
      int v = chooser.showOpenDialog(desktop);

      desktop.requestFocus();
      switch (v) {
        case JFileChooser.APPROVE_OPTION:
          if (chooser.getSelectedFile() != null) {
            if (chooser.getSelectedFile().exists()) {
              choice = chooser.getSelectedFile();
            }
            else {
              File parentFile = new File(chooser.getSelectedFile().getParent());
              choice = parentFile;
            }
            setField(DOML_PATH, choice.getPath(), "label");
          }
          break;

        case JFileChooser.CANCEL_OPTION:
        case JFileChooser.ERROR_OPTION:

          chooser.removeAll();
          chooser = null;

      }
    }
  }



}
