/*
LoaderGenerator - tool for generated xml, sql and doml file needed for Octopus.


    Copyright (C) 2003  Together

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package org.webdocwf.util.loader.wizard;

import javax.swing.*;
import javax.swing.event.*;
import java.util.*;
import java.io.*;
import java.awt.*;
import java.awt.event.*;
import org.webdocwf.util.loader.generator.LoaderGenerator;
import org.webdocwf.util.loader.generator.BufferClass;
import org.webdocwf.util.loader.LoaderException;

/**
 *
 * ExecThread class execute thread which control LoaderGenerator application
 * @author Radoslav Dutina
 * @version 1.0
 */
public class OctopusGeneratorThread extends Thread{
  private OctopusGeneratorData initData;
//  TraceDialog td = null; //trace dialog of this Thread
  private JTextArea td;
  private JDesktopPane desktop;
  private String errorMsg=null;


  private OctopusGenerator generator;


  /**
   * Construct object ExecThread with associated parameters.
   * @param desktop is desktop frame of wizard application
   * @param entry is object which contain input parameters of wizard application
   * @param errorMsg is error message
   */
  public OctopusGeneratorThread(JDesktopPane desktop,
      OctopusGeneratorData initData, String errorMsg,
      JTextArea traceArea) {
    this.initData=initData;
    this.desktop=desktop;
    this.errorMsg=errorMsg;
    td = traceArea;
//    desktop.add(td);
  }

  /**
     * This method append line in to trace area
     * @param s is value which to be set
     */
    public void appendLine(String s) {
      td.append(s);
      td.getCaret().setDot(td.getText().length() - 1);
    }


  /**
   * Run the thread
   */
  public void run() {

    td.setVisible(true);
//    td.setDefaultFocus();
    if(errorMsg!=null){
      appendLine(errorMsg+"\n");
//      td.setButtonEnabled();
//      td.setButtonName("OK");

    }else{
      try {
        OctopusGenerator generator = new OctopusGenerator(initData);
        String[] process=generator.generateAll();
        GeneratorThread generatorThread=null;
        if (process.length!=0) {
          BufferClass.getInstance();
          BufferClass.getInstance().setUsed();

          generatorThread=new GeneratorThread(process);
          generatorThread.start();

          while(generatorThread.isAlive()) {
            String value=BufferClass.getInstance().readFromBuffer();
            if(value.indexOf("***TogetherGroop***")==-1)
              appendLine(value+"\n");
            else
              break;
          }
//          td.setButtonEnabled();
        }else{
          appendLine("Some error is occur!"+"\n");
        }
//        td.setButtonName("OK");
//        setTitle("Building OctopusGenerator Application (Done)");
        generator=null;

      } catch (Exception e) {
        appendLine(e.getMessage());
        try {
          Thread.sleep(100);
        }
        catch (Exception ex) {
          appendLine(ex.getMessage());
        }
//        td.setButtonEnabled();
//        td.setTitle("Building OctopusGenerator Application (ERROR)");
//        td.setButtonName("OK");
        BufferClass.getInstance().writeToBuffer("***TogetherGroop***");
        BufferClass.getInstance().empty();
        System.out.println(e.getMessage());
      }
      BufferClass.getInstance().empty();
    }
  }

  /**
   * This class creates new thread
   */
  class GeneratorThread extends Thread{
    private String[] args;

    /**
     * Initialise the thread
     * @param args represents the arguments
     */
    public GeneratorThread(String[] args){
      this.args=args;
    }

    /**
     * Run the thread
     */
    public void run() {

      String generatorOutput=null;
      String valueMode=null;
      String domlUrl=null;
      String packageName=null;

      String sourceType=null;
      String sourceDataBase=null;
      String sourceDriverName=null;
      String sourceUser=null;
      String sourcePassword=null;

      String targetType=null;
      String targetDataBase=null;
      String targetDriverName=null;
      String targetUser=null;
      String targetPassword=null;

      //Output mode
      //main
      String generateXml=null;
      String generateDoml=null;
      //for generate sql
      String generateDropTableStmt=null;
      String generateDropIntegrityStmt=null;
      String generateCreateTableStmt=null;
      String generateCreatePKStmt=null;
      String generateCreateFKStmt=null;
      String generateCreateIndexStmt=null;

      //for genrate sql for all vendors
      String generateSqlForAllVendors=null;
      //optimized modes
      String fullMode=null;

      String includeTableList=null;
      String confJarStructure=null;


      if(args.length > 8 && args.length < 53){
        for (int i = 0; i < args.length - 1; i = i + 1) {
          if (args[i].equalsIgnoreCase("-st"))
            sourceType = args[++i];
          else if (args[i].equalsIgnoreCase("-sdb"))
            sourceDataBase = args[++i];
          else if (args[i].equalsIgnoreCase("-m"))
            valueMode = args[++i];
          else if (args[i].equalsIgnoreCase("-o"))
            generatorOutput = args[++i];
          else if (args[i].equalsIgnoreCase("-sdn"))
            sourceDriverName = args[++i];
          else if (args[i].equalsIgnoreCase("-tdn"))
            targetDriverName = args[++i];
          else if (args[i].equalsIgnoreCase("-tdb"))
            targetDataBase = args[++i];
          if (args[i].equalsIgnoreCase("-tt"))
            targetType = args[++i];
          if (args[i].equalsIgnoreCase("-su"))
            sourceUser = args[++i];
          if (args[i].equalsIgnoreCase("-sp"))
            sourcePassword = args[++i];
          if (args[i].equalsIgnoreCase("-tu"))
            targetUser = args[++i];
          if (args[i].equalsIgnoreCase("-tp"))
            targetPassword = args[++i];
          if (args[i].equalsIgnoreCase("-doml"))
            domlUrl = args[++i];
          if (args[i].equalsIgnoreCase("-pack"))
            packageName = args[++i];
          if (args[i].equalsIgnoreCase("-xml"))
            generateXml = args[++i];
          if (args[i].equalsIgnoreCase("-gdoml"))
            generateDoml = args[++i];
          if (args[i].equalsIgnoreCase("-sqlCT"))
            generateCreateTableStmt = args[++i];
          if (args[i].equalsIgnoreCase("-sqlDT"))
            generateDropTableStmt = args[++i];
          if (args[i].equalsIgnoreCase("-sqlDI"))
            generateDropIntegrityStmt = args[++i];
          if (args[i].equalsIgnoreCase("-sqlCPK"))
            generateCreatePKStmt = args[++i];
          if (args[i].equalsIgnoreCase("-sqlCFK"))
            generateCreateFKStmt = args[++i];
          if (args[i].equalsIgnoreCase("-sqlCI"))
            generateCreateIndexStmt = args[++i];
          if (args[i].equalsIgnoreCase("-sqlAll"))
            generateSqlForAllVendors = args[++i];
          if (args[i].equalsIgnoreCase("-fm"))
            fullMode = args[++i];
          if (args[i].equalsIgnoreCase("-it"))
            includeTableList = args[++i];
          if (args[i].equalsIgnoreCase("-cjs"))
            confJarStructure = args[++i];
        }
      }
      else {
        System.out.println("You didn't enter all required parameters, for running the application!");
        BufferClass.getInstance().writeToBuffer("You didn't enter all required parameters, for running the application!");
        printUsage();
      }
      try{

        LoaderGenerator generator=new LoaderGenerator(sourceType, sourceDataBase, valueMode,
            generatorOutput, sourceDriverName, targetDriverName, targetDataBase, targetType,
            sourceUser, sourcePassword, targetUser, targetPassword, domlUrl,
            packageName,generateDropTableStmt,generateDropIntegrityStmt,generateCreateTableStmt,
            generateCreatePKStmt,generateCreateFKStmt,generateCreateIndexStmt,
            generateSqlForAllVendors,generateXml, generateDoml, fullMode, includeTableList,
            confJarStructure);

        generator.generate();

      } catch (LoaderException le) {
        System.out.println(le.getMessage());
        String message=le.getMessage();
        if(message==null||message.indexOf(-1)!=-1||message.indexOf(0)!=-1)
          message="Application build fails!";
        BufferClass.getInstance().writeToBuffer(message+"\n");
        BufferClass.getInstance().writeToBuffer("Check input parameters!" + "\n");
        try {
          Thread.sleep(100);
        }
        catch (Exception ex) {
          appendLine(ex.getMessage());
        }
//        td.setTitle("Building OctopusGenerator Application (ERROR)");
//        td.setButtonEnabled();
//        td.setButtonName("OK");
        BufferClass.getInstance().writeToBuffer("***TogetherGroop***");
        return;
      } catch (Throwable th) {
        BufferClass.getInstance().writeToBuffer(th.getMessage());
        try {
          Thread.sleep(100);
        }
        catch (Exception ex) {
          appendLine(ex.getMessage());
        }
//        td.setTitle("Building OctopusGenerator Application (ERROR)");
//        td.setButtonEnabled();
//        td.setButtonName("OK");
        BufferClass.getInstance().writeToBuffer("***TogetherGroop***");
        th.printStackTrace(System.out);
        return;
      }
      try {
        Thread.sleep(1000);
      }
      catch (Exception ex) {
        appendLine(ex.getMessage());
      }
      BufferClass.getInstance().writeToBuffer("***TogetherGroop***");
    }

    /**
     * Help for Octopus Loader application
     */
    public void printUsage () {
      System.out.println("Usage: java org.webdocwf.util.loader.generator.Generator [options] ");
    BufferClass.getInstance().writeToBuffer("Usage: java org.webdocwf.util.loader.generator.Generator [options] ");
    System.out.println(" Options:");
    BufferClass.getInstance().writeToBuffer(" Options:");
    System.out.println(" -st sourceType, defines the type of the source database.");
    BufferClass.getInstance().writeToBuffer(" -st sourceType, defines the type of the source database.");
    System.out.println(" -tt targetType, defines the type of the target database.");
    BufferClass.getInstance().writeToBuffer(" -tt targetType, defines the type of the target database.");
    System.out.println(" -sdn sourceDriverName, represents driver of defined source database.");
    BufferClass.getInstance().writeToBuffer(" -sdn sourceDriverName, represents driver of defined source database.");
    System.out.println(" -tdn targetDriverName, represents driver of defined target database.");
    BufferClass.getInstance().writeToBuffer(" -tdn targetDriverName, represents driver of defined target database.");
    System.out.println(" -sdb sourceDatabase, defines the place where you're put the database tables");
    BufferClass.getInstance().writeToBuffer(" -sdb sourceDatabase, defines the place where you're put the database tables");
    System.out.println(" -tdb targetDataBase defines the place where the target database tables are.");
    BufferClass.getInstance().writeToBuffer(" -tdb targetDataBase defines the place where the target database tables are.");
    System.out.println(" -m valueMode, is the difference from overwrite and update attribute");
    BufferClass.getInstance().writeToBuffer(" -m valueMode, is the difference from overwrite and update attribute");
    System.out.println(" -su sourceUser, defines the user of the source database.");
    BufferClass.getInstance().writeToBuffer(" -su sourceUser, defines the user of the source database.");
    System.out.println(" -sp sourcePassword, defines user password for the source database.");
    BufferClass.getInstance().writeToBuffer(" -sp sourcePassword, defines user password for the source database.");
    System.out.println(" -tu targetUser, defines the user of the target database.");
    BufferClass.getInstance().writeToBuffer(" -tu targetUser, defines the user of the target database.");
    System.out.println(" -tp targetPassword, defines user password for the target database.");
    BufferClass.getInstance().writeToBuffer(" -tp targetPassword, defines user password for the target database.");
    System.out.println(" -doml domlUrl, defines the place where the doml file is placed.");
    BufferClass.getInstance().writeToBuffer(" -doml domlUrl, defines the place where the doml file is placed.");
    System.out.println(" -o generatorOutput, is optional. That represent the directory, where the Octopus place"+
                       " created files. If this argument dont exists, Octopus place created files in to current direcory!");
    BufferClass.getInstance().writeToBuffer(" -o generatorOutput, is optional. That represent the directory, where the Octopus place"+
                                            " created files. If this argument dont exists, Octopus place created files in to current direcory!");
    System.out.println(" -pack packageName, defines the package name for the generated doml file.");
    BufferClass.getInstance().writeToBuffer(" -pack packageName, defines the package name for the generated doml file.");

    System.out.println(" -xml generateXml, defines if you want to generate xml files as output files. "+
                       "    Possible values are true and false.");
    BufferClass.getInstance().writeToBuffer(" -xml generateXml, defines if you want to generate xml files as output files. "+
                       "    Possible values are true and false.");
    System.out.println(" -gdoml generateDoml, defines if you want to generate doml file as output file. "+
                       "    Possible values are true and false.");
    BufferClass.getInstance().writeToBuffer(" -gdoml generateDoml, defines if you want to generate doml file as output file. "+
                       "    Possible values are true and false.");
    System.out.println(" -sqlCT generateCreateTables, defines if you want to generate only Sql statement for CREATE TABLE.");
    BufferClass.getInstance().writeToBuffer(" -sqlCT generateCreateTables, defines if you want to generate only Sql statement for CREATE TABLE.");

    System.out.println(" -sqlDT generateDropTableStmt, defines if you want to generate only Sql statement for DROP TABLE.");
    BufferClass.getInstance().writeToBuffer(" -sqlDT generateDropTableStmt, defines if you want to generate only Sql statement for DROP TABLE.");

    System.out.println(" -sqlCPK generateCreatePrimaryKeys, defines if you want to generate only Sql statement for ALTER TABLE ADD CONSTRAINT (PRIMARY KEY).");
    BufferClass.getInstance().writeToBuffer(" -sqlCPK generateCreatePrimaryKeys, defines if you want to generate only Sql statement for ALTER TABLE ADD CONSTRAINT (PRIMARY KEY).");

    System.out.println(" -sqlCFK generateCreateForeigKeys, defines if you want to generate only Sql statement for ALTER TABLE ADD CONSTRAINT (FOREIGN KEY).");
    BufferClass.getInstance().writeToBuffer(" -sqlCFK generateCreateForeigKeys, defines if you want to generate only Sql statement for ALTER TABLE ADD CONSTRAINT (FOREIGN KEY).");

    System.out.println(" -sqlCI generateCreateIndex, defines if you want to generate only Sql statement for CREATE INDEX.");
    BufferClass.getInstance().writeToBuffer(" -sqlCI generateCreateIndex, defines if you want to generate only Sql statement for CREATE INDEX.");

    System.out.println(" -fm fullMode, defines the mode of output xml files. Possible values are true and false.");
    BufferClass.getInstance().writeToBuffer("  -fm fullMode, defines the mode of output xml files. Possible values are true and false.");

    System.out.println(" -it includeTableList, defines tables which you want to incude into Generator process.");
    BufferClass.getInstance().writeToBuffer("  -it includeTableList, defines tables which you want to incude into Generator process.");


    System.out.println("For more details, see documentation.");
    BufferClass.getInstance().writeToBuffer("For more details, see documentation.");
    }
  }
}
