package org.webdocwf.util.loader.wizard;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.border.*;

public class WizardFrame
    extends JFrame {
  private WizardFrame wizardFrame;
  private JDesktopPane desktop;
  private JPopupMenu popUp;
  private static boolean startOctopusLoader=false;
  private static String pathToXmlFile="";
  private static String confJarStructure="";


  public WizardFrame(String title) {
    super(title);
    wizardFrame = this;
    setDefaultCloseOperation(EXIT_ON_CLOSE);
    desktop = new JDesktopPane();
    setContentPane(desktop);

    // Install our custom desktop manager.
    desktop.setDesktopManager(new SampleDesktopMgr());
    desktop.setBackground(new Color(210, 210, 210));

    createMenuBar();
    createPopupMenu();

    if(startOctopusLoader==true){
      OctopusLoaderFrame loaderFrame = createOctopusLoaderInitFrame();
      try {
        loaderFrame.setOctopusLoaderInit(new OctopusLoaderData(), pathToXmlFile,
            confJarStructure);
        desktop.add(loaderFrame);
        loaderFrame.setVisible(true);
      }
      catch(Exception ex) {
        String message = ex.getMessage();
        String message2 = "Check the OCTOPUS_HOME variable!";
        JOptionPane error = new JOptionPane();
        error.showMessageDialog(desktop, message + "\n" + message2, "Error", 0);
        error.setVisible(true);
        System.exit(0);
      }
    }
  }

  protected void createMenuBar() {
    JMenuBar mb = new JMenuBar();
    JMenu menu = new JMenu("Applications");
    JMenu menu2 = new JMenu("IDEOption");
    JMenu menu3 = new JMenu("Help");

    menu.add(new OctopusGenerator()); // add octopus Generator frame
    menu.add(new OctopusLoader()); // add octopus Loader frame
    menu2.add(new LnFActionMetal()); // add look and feel option
    menu2.add(new LnFActionMotif());
    menu2.add(new LnFActionWindows());
    menu2.add(new LnFActionJava());
    menu3.add(new OctopusHelpAction());
    menu3.addSeparator();
    menu3.add(new OctopusAboutAction());

    setJMenuBar(mb);
    mb.add(menu);
    mb.add(menu2);
    mb.add(menu3);
  }

  public void createPopupMenu() {
    JMenuItem menuItem;

    //Create the popup menu.
    JPopupMenu popup = new JPopupMenu();
    JMenuItem popupItem = new JMenuItem("Start OctopusGenerator application");
    popupItem.setAction(new OctopusGenerator());
    JMenuItem popupItem2 = new JMenuItem("Start OctopusLoader application");
    popupItem2.setAction(new OctopusLoader());

    popup.add(popupItem);
    popup.add(popupItem2);

    //Add listener to the destop area so the popup menu can come up.
    MouseListener popupListener = new PopupListener(popup);
    desktop.addMouseListener(popupListener);
  }

  public static void main(String[] args) {
    OctopusSplash octopusSplash = new OctopusSplash("splash_octopus.gif", null);

    if(args.length>0 && args.length<5){
      for(int i=0; i<args.length-1;i=i+1){
        if (args[i].equalsIgnoreCase("-sol")) {
          pathToXmlFile = args[++i];
          if (!pathToXmlFile.equalsIgnoreCase(""))
            startOctopusLoader = true;
        }
        if (args[i].equalsIgnoreCase("-cjs")) {
          confJarStructure = args[++i];
        }
      }
    }
    try {
      UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
    }
    catch(Exception e) {
      e.printStackTrace();
    }
    WizardFrame wizardFrame = new WizardFrame("Enhydra Octopus Application");

    wizardFrame.addWindowListener(
    	new WindowAdapter() {
    		public void windowClosing(WindowEvent we) {
    			System.exit(0);
    		}
    	}
    );

	 wizardFrame.setIconImage(new ImageIcon(WizardFrame.class.getResource("images/Enhydra16.gif")).getImage());

    Dimension dimension = Toolkit.getDefaultToolkit().getScreenSize();
    wizardFrame.setBounds(0, 0, dimension.width - 20, dimension.height - 40);

    try {
      Thread.sleep(2500);
    }
    catch(Exception e) {
    e.printStackTrace();
    }
    octopusSplash.getSplash().hideSplash();
    octopusSplash = null;
    wizardFrame.setVisible(true);
  }

  private OctopusGeneratorFrame createOctopusGeneratorInitFrame() {
    OctopusGeneratorFrame frame = new OctopusGeneratorFrame(desktop);
    setDefaultCloseOperation(DISPOSE_ON_CLOSE);
    return frame;
  }

  private OctopusLoaderFrame createOctopusLoaderInitFrame(){
    OctopusLoaderFrame frame=new OctopusLoaderFrame(desktop);
    setDefaultCloseOperation(DISPOSE_ON_CLOSE);
    return frame;
  }


  private class OctopusGenerator
      extends AbstractAction {
    /**
     * Action which creates new frame
     */
    public OctopusGenerator() {
      putValue(NAME, "New Octopus Generator");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('G',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(SHORT_DESCRIPTION, "OctopusGenerator application");
      putValue(LONG_DESCRIPTION, "Start OctopusGenerator application");
      putValue(MNEMONIC_KEY, new Integer('G'));
    }

    public void actionPerformed(ActionEvent e) {
      OctopusGeneratorFrame octopusGenerator = createOctopusGeneratorInitFrame();
      try {
        octopusGenerator.setOctopusGeneratorInit(new OctopusGeneratorData(confJarStructure),
            confJarStructure);
      }
      catch(Exception ex) {
        String message = ex.getMessage();
        String message2 = "Check the OCTOPUS_HOME variable!";
        JOptionPane error = new JOptionPane();
        error.showMessageDialog(desktop, message + "\n" + message2, "Error", 0);
        error.setVisible(true);
        System.exit(0);
      }

      desktop.add(octopusGenerator);
      octopusGenerator.setVisible(true);

    }
  }

  private class OctopusLoader
      extends AbstractAction {
    /**
     * Action which creates new frame
     */
    public OctopusLoader() {
      putValue(NAME, "New Octopus Loader");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('O',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(SHORT_DESCRIPTION, "OctopusLoader application");
      putValue(LONG_DESCRIPTION, "Start OctopusLoader application");
      putValue(MNEMONIC_KEY, new Integer('O'));
    }

    public void actionPerformed(ActionEvent e) {
      OctopusLoaderFrame octopusLoader= createOctopusLoaderInitFrame();
            try{
              octopusLoader.setOctopusLoaderInit(new OctopusLoaderData(), null,confJarStructure);
              desktop.add(octopusLoader);
              octopusLoader.setVisible(true);
            }catch(Exception ex){
              String message=ex.getMessage();
              String message2="Check the OCTOPUS_HOME variable!";
              JOptionPane error=new JOptionPane();
              error.showMessageDialog(desktop,message+"\n"+message2,"Error",0);
              error.setVisible(true);
              System.exit(0);
            }
    }
  }

  private class LnFActionMetal
      extends AbstractAction {

    public LnFActionMetal() {

      putValue(NAME, "Metal Look$Feel");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('M',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(SHORT_DESCRIPTION, "Metal Look & Feel");
      putValue(LONG_DESCRIPTION, "Set Metal Look & Feel Model");
      putValue(MNEMONIC_KEY, new Integer('M'));
    }

    public void actionPerformed(ActionEvent e) {
      LnFListener lnf = new LnFListener(wizardFrame);
      lnf.actionPerformed(e);
    }
  }

  private class LnFActionMotif
      extends AbstractAction {

    public LnFActionMotif() {

      putValue(NAME, "Motif Look$Feel");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('F',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(SHORT_DESCRIPTION, "Motif Look & Feel");
      putValue(LONG_DESCRIPTION, "Set Motif Look & Feel Model");
      putValue(MNEMONIC_KEY, new Integer('F'));
    }

    public void actionPerformed(ActionEvent e) {
      LnFListener lnf = new LnFListener(wizardFrame);
      lnf.actionPerformed(e);
    }
  }

  private class LnFActionWindows
      extends AbstractAction {

    public LnFActionWindows() {

      putValue(NAME, "Windows Look$Feel");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('W',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(SHORT_DESCRIPTION, "Windows Look & Feel");
      putValue(LONG_DESCRIPTION, "Set Windows Look & Feel Model");
      putValue(MNEMONIC_KEY, new Integer('W'));
    }

    public void actionPerformed(ActionEvent e) {
      LnFListener lnf = new LnFListener(wizardFrame);
      lnf.actionPerformed(e);
    }
  }

  private class LnFActionJava
      extends AbstractAction {

    public LnFActionJava() {

      putValue(NAME, "Java Look$Feel");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('J',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(SHORT_DESCRIPTION, "Java Look & Feel");
      putValue(LONG_DESCRIPTION, "Set Java Look & Feel Model");
      putValue(MNEMONIC_KEY, new Integer('J'));
    }

    public void actionPerformed(ActionEvent e) {
      LnFListener lnf = new LnFListener(wizardFrame);
      lnf.actionPerformed(e);
    }
  }

  class PopupListener
      extends MouseAdapter {
    JPopupMenu popup;

    PopupListener(JPopupMenu popupMenu) {
      popup = popupMenu;
    }

    public void mousePressed(MouseEvent e) {
      showPopup(e);
    }

    public void mouseReleased(MouseEvent e) {
      showPopup(e);
    }

    private void showPopup(MouseEvent e) {
      if(e.isPopupTrigger()) {
        popup.show(e.getComponent(), e.getX(), e.getY());
      }
    }
  }

  private class OctopusHelpAction
      extends AbstractAction {

    /**
     * Action which creates new help frame
     */
    public OctopusHelpAction() {
      putValue(NAME, "Help");
      putValue(SMALL_ICON,
          new ImageIcon(getClass().getClassLoader().getResource("org/webdocwf/util/loader/" +
          "wizard/images/Help16.gif")));
      putValue(SHORT_DESCRIPTION, "Help for running the program");
      putValue(LONG_DESCRIPTION, "Help for running the program");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('H',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(MNEMONIC_KEY, new Integer('H'));
    }

    /**
     * Creating event for new windows help frame
     * @param e is creating events
     */
    public void actionPerformed(ActionEvent e) {
      try {
        OctopusGeneratorHelpFrame helpFrame = new OctopusGeneratorHelpFrame();
        helpFrame.setIconImage(new ImageIcon(getClass().getClassLoader().getResource(
            "org/webdocwf/util/loader/" +
            "wizard/images/Enhydra16.gif")).getImage());
        helpFrame.setVisible(true);
      }
      catch(Exception ex) {
        String message = ex.getMessage();
        String message2 = "Check the OCTOPUS_HOME variable!";
        JOptionPane error = new JOptionPane();
        error.showMessageDialog(desktop, message + "\n" + message2, "Error", 0);
        error.setVisible(true);
        System.exit(0);
      }
    }
  }

  private OctopusAboutFrame createOctopusAboutFrame() {
    OctopusAboutFrame frame = new OctopusAboutFrame(this.desktop);
    setDefaultCloseOperation(DISPOSE_ON_CLOSE);
    return frame;
  }

  private class OctopusAboutAction
      extends AbstractAction {
    /**
     * Action which creates new about frame
     */
    public OctopusAboutAction() {
      putValue(NAME, "About");
      putValue(SMALL_ICON,
          new ImageIcon(getClass().getClassLoader().getResource("org/webdocwf/util/loader/" +
          "wizard/images/About16.gif")));
      putValue(SHORT_DESCRIPTION, "Abouth the program");
      putValue(LONG_DESCRIPTION, "Abouth the program");
      putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke('A',
          Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()));
      putValue(MNEMONIC_KEY, new Integer('A'));
    }

    /**
     * Creating event for new windows about frame
     * @param e is creating events
     */
    public void actionPerformed(ActionEvent e) {
      try {
        OctopusAboutFrame aboutFrame = createOctopusAboutFrame();
//        aboutFrame.setIconImage(new ImageIcon(getClass().getClassLoader().getResource("org/webdocwf/util/loader/"+
//            "wizard/images/Enhydra16.gif")).getImage());
        desktop.add(aboutFrame);
        aboutFrame.setVisible(true);

      }
      catch(Exception ex) {
        String message = ex.getMessage();
        String message2 = "Check the OCTOPUS_HOME variable!";
        JOptionPane error = new JOptionPane();
        error.showMessageDialog(desktop, message + "\n" + message2, "Error", 0);
        error.setVisible(true);
        System.exit(0);
      }
    }
  }

}